@@ -17,7 +17,7 @@
 import sys
 import re
 import xml.dom.minidom
-from calculate.lib.utils.common import _error
+from calculate.lib.cl_template import TemplateFormat
 
 from calculate.lib.cl_lang import setLocalTranslate
 
@@ -25,7 +25,7 @@ _ = lambda x: x
 setLocalTranslate('cl_lib3', sys.modules[__name__])
 
 
-class patch(_error):
+class patch(TemplateFormat):
     """Класс для замены, добавления, удаления, строк в файле"""
     # root нода
     rootNode = False
@@ -34,8 +34,7 @@ class patch(_error):
     # Текст шаблона
     text = ""
 
-    def __init__(self, text):
-        self.text = text
+    def prepare(self):
         # Создаем XML документ
         self.doc = self.textToXML()
         if self.doc:
@@ -62,7 +61,7 @@ class patch(_error):
     def setDotall(self):
         self.reFlags |= re.S
 
-    def processingFile(self, textConfigFile, rootPath=None):
+    def processingFile(self, textConfigFile, rootPath=None, nameFile=None):
         """Обработка конфигурационного файла"""
         if not self.doc:
             self.setError(_("Failed to convert the text template to XML"))
