@@ -323,7 +323,7 @@ def getVideoFromXorgLog(prefix="/", available_drivers=()):
                         filter(lambda x: "drv" in x and reDriver.search(x),
                                readLinesFile(xorg_log_file)))))
                 if matchStrs:
-                    reUnload = re.compile('|'.join('UnloadModule: "(%s)"' % x
+                    reUnload = re.compile('UnloadModule: "(%s)"' %'|'.join(x
                         for x in matchStrs))
                     matchUnload = [x.group(1) for x in 
                         (reUnload.search(x) for x in 
